### CPU temperature stress test on a RPi using **rpi_tempmon.py** program.


Specifications Test 1-6: Raspberry pi 3 model B, running Raspbian 10.0 Buster.
Offical Standard Rpi plastic case from Rpi store.

Specifications Test 7: Raspberry 5, running Raspbian 12.0 Bookworm.
Offical Standard Rpi plastic case + fan from Rpi store.

The CPU will be stressed and temperature measurements taken and graphed for
a variety of cooling solutions.
ARM CPU temperature measurements by software **[rpi_tempmon.py](https://github.com/gavinlyonsrepo/raspberrypi_tempmon)** stress test  option.
Rpi_tempmon uses the sysbench benchmarking tool to stress CPU.
The CPU stress test consists of calculation of prime numbers up to a value of 20000. 
All calculations are performed using 64-bit integers. 4 worker threads are created.
CPU temperature and freq are recorded for each test run and graphed.
5 test iterations per test. Test 2-6 duration: 10 minutes, Test 1 duration 12 minutes due to
thermal throttling slowing down CPU.

The first graph is created in libreoffice calc by using CSV(comma separted values) 
log file data produced by **rpi_tempmon.py** during testing.
The other graphs are generated by rpi_tempmon.py at end of testrun.

* Test 1 - RPI3 No Heatsink .
* Test 2 - RPI3 Small Heatsink 13 by 15 by 7 (mm).
* Test 3 - RPI3 Medium Heatsink 16 by 22 by 7 (mm).
* Test 4 - RPI3 Large heatsink  35 by 35 by 22 (mm).
* Test 5 - RPI3 Small Heatsink + 60mm fan running at 5V.
* Test 6 - RPI3 Small Heatsink + 80mm fan running at 9V.
* Test 7 - RPI 5 Official RPI basic Kit case + fan and small heatsink.

-------------


* All Data graph. (test 1-6)


![all data graph](https://raw.githubusercontent.com/gavinlyonsrepo/raspberrypi_tempmon/master/Documentation/stresstestdata/alldata.jpg)

------------


* Test 1 - No Heatsink.

![test1 graph](https://raw.githubusercontent.com/gavinlyonsrepo/raspberrypi_tempmon/master/Documentation/stresstestdata/test1.jpg)

* Test 2 - small Heatsink 13 by 15 by 7 (mm).

![test2 graph](https://raw.githubusercontent.com/gavinlyonsrepo/raspberrypi_tempmon/master/Documentation/stresstestdata/test2.jpg)

* Test 3 - Small + medium Heatsink 16 by 22 by 7 (mm).

![test3 graph](https://raw.githubusercontent.com/gavinlyonsrepo/raspberrypi_tempmon/master/Documentation/stresstestdata/test3.jpg)

* Test 4 - Small + medium + large heatsink  35 by 35 by 22 (mm).

![test4 graph](https://raw.githubusercontent.com/gavinlyonsrepo/raspberrypi_tempmon/master/Documentation/stresstestdata/test4.jpg)

* Test 5 - Small Heatsink + 70mm fan running at 5V.

![test5 graph](https://raw.githubusercontent.com/gavinlyonsrepo/raspberrypi_tempmon/master/Documentation/stresstestdata/test5.jpg)

* Test 6 - Small heatsink + 80mm fan running at 9V.

![test6 graph](https://raw.githubusercontent.com/gavinlyonsrepo/raspberrypi_tempmon/master/Documentation/stresstestdata/test6.jpg)

* Test 7 - RPI 5 Official RPI basic Kit case + fan and small heatsink

![test7 graph](https://raw.githubusercontent.com/gavinlyonsrepo/raspberrypi_tempmon/master/Documentation/stresstestdata/test7.jpg)
.
